package it.polito.bigdata.spark.sparkmllib;

import org.apache.spark.api.java.function.Function;
import org.apache.spark.mllib.regression.LabeledPoint;
import org.apache.spark.mllib.linalg.Vectors;
import org.apache.spark.mllib.linalg.Vector;

@SuppressWarnings("serial")
public class InputRecord implements Function<String, LabeledPoint> {

	public LabeledPoint call(String record) {
		String[] fields = record.split(",");
		
		// Fields of 0 contains the id of the class
		double classLabel = Double.parseDouble(fields[0]);

		// The other cells of fields contain the (numerical) values of the attributes
		// Create an array of doubles containing these values 
		double[] attributesValues = new double[fields.length-1];
	    
		for (int i = 0; i < fields.length-1; ++i) {
			attributesValues[i] = Double.parseDouble(fields[i+1]);
		}
		
		// Create a dense vector based in the content of attributesValues
		Vector attrValues= Vectors.dense(attributesValues);

		// Return a new LabeledPoint
		return new LabeledPoint(classLabel, attrValues);
	}

}
